from setuptools import setup

setup(name='dist_prob_gb',
      version='1.0',
      description='Gaussian and Binomial distributions',
      packages=['dist_prob_gb'],
      author = 'Ismail Musharaf',
      author_email = 'ismailmushraf@gmail.com',
      zip_safe=False)
